
/*
 * STAGE: Import data into SAS 
 */
FILENAME REFFILE '/folders/myfolders/Week1/Data/NC_MEDICARE_PHYSICIAN.csv';

PROC IMPORT DATAFILE=REFFILE
	DBMS=CSV
	OUT=WORK.MEDICARE_PHYSICIAN REPLACE;
	GETNAMES=YES;
	GUESSINGROWS=2000;
RUN;

PROC CONTENTS DATA=WORK.MEDICARE_PHYSICIAN; 
RUN;

proc print data=work.MEDICARE_PHYSICIAN(obs=10);
	title 'The First 10 observations for NC MEDICARE PHYSICIAN Data Set';
run; 

/*
 * STRUCTURE: Sort on Provider ID, remove any duplicates
 */
DATA medicare_physician;
	LENGTH average_benifit 8.;
	FORMAT average_benifit dollar10.2;
	SET medicare_physician;
	average_benifit = total_submitted_charge_amt / Num_of_Medicare_Beneficiaries;
RUN;

PROC SORT DATA=work.medicare_physician 
	OUT=work.medicare_physician_sort(keep=National_Provider_Identifier 
									Last_Name 
									First_Name 
									Middle_Initial 
									Credentials 
									Gender 
									Entity_Type 
									Street_Address_1 
									Street_Address_2 
									City_Name 
									Zip_Code 
									State_Code 
									Provider_Type 
									Num_of_Services 
									Num_of_Medicare_Beneficiaries 
									Total_Submitted_Charge_Amt
									average_benifit
									Average_Age_of_Beneficiaries )
									NODUP;
	BY National_Provider_Identifier;
RUN; 	


PROC FREQ data=work.medicare_physician_sort ;
	table city_name / out=freq_out;
	WHERE city_name IN ('ASHEVILE','ASHERVILLE', 'ASHEVILLE, NC', 'ASHEVLLE', 'ASHVILLE','ASHEVILLE', 'FUQUAY-VARINA', 'FUQUAY VARINA', 'CARY', 'APEX', 'HOLLY SPRINGS', 'RALEIGH', 'GARNER', 'KNIGHTDALE', 'ZEBULON', 'MORRISVILLE', 'ROESVILLE', 'WENDELL');
run; 

/*
 * CLEAN: clean up Fuquay-Varina and Ascheville with MODIFY
 */
DATA work.medicare_physician_sort;
	MODIFY work.medicare_physician_sort;
	if City_Name EQ 'FUQUAY-VARINA' then City_Name = 'FUQUAY VARINA';
	if city_name IN('ASHEVILE','ASHERVILLE', 'ASHEVILLE, NC', 'ASHEVLLE', 'ASHVILLE') then city_name = 'ASHEVILLE';
RUN;

PROC FREQ data=work.medicare_physician_sort ;
	table city_name / out=freq_out;
	WHERE city_name IN ('ASHEVILLE', 'FUQUAY VARINA', 'CARY', 'APEX', 'HOLLY SPRINGS', 'RALEIGH', 'GARNER', 'KNIGHTDALE', 'ZEBULON', 'MORRISVILLE', 'ROESVILLE', 'WENDELL');
run; 

/*
 * ANALYZE: simple cluster of medicare benificiaries vs. total submitted charge amount
 * 
 */
PROC FASTCLUS data=work.medicare_physician_sort out=clus maxclusters=5;
	var total_submitted_charge_amt Num_of_Medicare_Beneficiaries ;
RUN;

proc sgplot data=clus;
	title 'Medicare Physician Clusters';
      scatter x=total_submitted_charge_amt y=Num_of_Medicare_Beneficiaries / group=cluster;
RUN;
/*
 * FILTER : remove physicians with large number of benificiaries, write out an anomaly file. 
 * 
 */
DATA nc_anomalies medicare_physician_sort;
	modify medicare_physician_sort;
	IF (total_submitted_charge_amt < 400000) AND (Num_of_Medicare_Beneficiaries < 10000) THEN DO;
		replace medicare_physician_sort;
	END;
	ELSE DO;
		output nc_anomalies;
		remove medicare_physician_sort;
	END;
RUN;	
/*
 * RERUN Aanalysis 
 */
PROC FASTCLUS data=work.medicare_physician_sort out=clus maxclusters=5;
	var total_submitted_charge_amt  Num_of_Medicare_Beneficiaries ;
RUN;
proc means data=medicare_physician_sort ;
	var Num_of_Medicare_Beneficiaries;
run;
	
proc sgplot data=clus;
	title 'Medicare Physician Clusters';
      scatter x=total_submitted_charge_amt y=Num_of_Medicare_Beneficiaries / group=cluster;
      refline 996 /axis=y label="3 STDEV above the Mean (" lineattrs=(color=green);
RUN;
